Enum jsonwebtoken::errors::Error [] [src]

pub enum Error {
    EncodeJSON(EncoderError),
    DecodeBase64(FromBase64Error),
    DecodeJSON(DecoderError),
    Utf8(FromUtf8Error),
    InvalidToken,
    InvalidSignature,
    WrongAlgorithmHeader,
}

All the errors we can encounter while signing/verifying tokens and a couple of custom one for when the token we are trying to verify is invalid

Variants

EncodeJSON
DecodeBase64
DecodeJSON
Utf8
InvalidToken
InvalidSignature
WrongAlgorithmHeader